<div align="center">
  <img src="./logo.png" alt="vizeer Logo" width="200">
  <h1>Vizeer</h1>
  <p>A video contact sheet generator</p>
  <a href="https://github.com/walidsa3d/actions/workflows/test.yml">
    <img src="https://img.shields.io/github/actions/workflow/status/walidsa3d/vizeer/test.yml?branch=main&style=flat-square" alt="Test Status">
  </a>
  <a href="https://github.com/walidsa3d/vizeer/blob/main/LICENSE">
    <img src="https://img.shields.io/github/license/walidsa3d/vizeer?style=flat-square" alt="License">
  </a>
</div>

Vizeer A video contact sheet generator

## 🚀 Features


## Installation
```
pip install vizeer
```

## Usage
```
vizeer sample.mkv -o sample.png
```

## 🧑‍💻 Contributing

Contributions are welcome! Please feel free to submit a Pull Request.

## 📄 License
This project is licensed under the MIT License. See the LICENSE file for more details.


